# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.6.1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class OutpostHealth(BaseModel):
    """
    Outpost health status
    """ # noqa: E501
    uid: StrictStr
    last_seen: datetime
    version: StrictStr
    golang_version: StrictStr
    openssl_enabled: StrictBool
    openssl_version: StrictStr
    fips_enabled: Optional[StrictBool] = Field(description="Get FIPS enabled")
    version_should: StrictStr
    version_outdated: StrictBool
    build_hash: StrictStr
    build_hash_should: StrictStr
    hostname: StrictStr
    __properties: ClassVar[List[str]] = ["uid", "last_seen", "version", "golang_version", "openssl_enabled", "openssl_version", "fips_enabled", "version_should", "version_outdated", "build_hash", "build_hash_should", "hostname"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OutpostHealth from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "uid",
            "last_seen",
            "version",
            "golang_version",
            "openssl_enabled",
            "openssl_version",
            "fips_enabled",
            "version_should",
            "version_outdated",
            "build_hash",
            "build_hash_should",
            "hostname",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if fips_enabled (nullable) is None
        # and model_fields_set contains the field
        if self.fips_enabled is None and "fips_enabled" in self.model_fields_set:
            _dict['fips_enabled'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OutpostHealth from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "uid": obj.get("uid"),
            "last_seen": obj.get("last_seen"),
            "version": obj.get("version"),
            "golang_version": obj.get("golang_version"),
            "openssl_enabled": obj.get("openssl_enabled"),
            "openssl_version": obj.get("openssl_version"),
            "fips_enabled": obj.get("fips_enabled"),
            "version_should": obj.get("version_should"),
            "version_outdated": obj.get("version_outdated"),
            "build_hash": obj.get("build_hash"),
            "build_hash_should": obj.get("build_hash_should"),
            "hostname": obj.get("hostname")
        })
        return _obj


